==> cube-manager-3.2.0-3.2.0-sources.jar: org/gcube/data/analysis/tabulardata/cube/time/DayCodelistCreator.java <==
package org.gcube.data.analysis.tabulardata.cube.time;

import java.util.Arrays;
import java.util.List;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.gcube.data.analysis.tabulardata.cube.data.DatabaseWrangler;
import org.gcube.data.analysis.tabulardata.cube.metadata.CubeMetadataWrangler;
import org.gcube.data.analysis.tabulardata.model.column.Column;
import org.gcube.data.analysis.tabulardata.model.column.factories.AttributeColumnFactory;
import org.gcube.data.analysis.tabulardata.model.column.factories.CodeColumnFactory;
import org.gcube.data.analysis.tabulardata.model.column.factories.IdColumnFactory;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.IdColumnType;
import org.gcube.data.analysis.tabulardata.model.datatype.DateType;
import org.gcube.data.analysis.tabulardata.model.datatype.IntegerType;
import org.gcube.data.analysis.tabulardata.model.datatype.TextType;
import org.gcube.data.analysis.tabulardata.model.metadata.common.ImmutableLocalizedText;
import org.gcube.data.analysis.tabulardata.model.metadata.common.LocalizedText;
import org.gcube.data.analysis.tabulardata.model.metadata.common.NamesMetadata;
import org.gcube.data.analysis.tabulardata.model.metadata.table.TimePeriodTypeMetadata;
import org.gcube.data.analysis.tabulardata.model.table.Table;
import org.gcube.data.analysis.tabulardata.model.table.type.TimeCodelistTableType;
import org.gcube.data.analysis.tabulardata.model.time.PeriodType;

import com.google.common.collect.Lists;

@Singleton
public class DayCodelistCreator implements TimeCodelistCreator {

	@Inject
	DatabaseWrangler dbWrangler;

	@Inject
	CubeMetadataWrangler cmWrangler;

	@Override
	public Table createTable() {
		Table dayCodelist = createTableMeta();

		String tableName = createTableOnDBWithColumns(dayCodelist.getColumns());
		dayCodelist.setName(tableName);
		
		return cmWrangler.save(dayCodelist, false);
	}

	private Table createTableMeta() {
		List<Column> columns = Lists.newArrayList(IdColumnFactory.create(), createCodeColumn(), createDayColumn(),
				createMonthColumn(), createQuarterColumn(), createYearColumn(), createDecadeColumn(),
				createIsoWeekColumn(), createIsoYearColumn());
		Table dayCodelist = new Table(new TimeCodelistTableType());
		dayCodelist.setColumns(columns);
		dayCodelist.setMetadata(new TimePeriodTypeMetadata(getManagedPeriodType()));
		return dayCodelist;
	}

	private String createTableOnDBWithColumns(List<Column> columns) {
		String tableName = dbWrangler.createTable();
		for (Column column : columns) {
			if (column.getColumnType() instanceof IdColumnType)
				continue;
			dbWrangler.addColumn(tableName, column.getName(), column.getDataType());
			dbWrangler.setNullable(tableName, column.getName(), false);
			if (column.getColumnType() instanceof CodeColumnType)
				dbWrangler.createUniqueIndex(tableName, column.getName());
		}
		dbWrangler.createInsertUpdateTriggerOnTable("update_time_dimension_"+tableName, tableName, "update_gregorian_day_dimension");
		return tableName;
	}

	private Column createIsoYearColumn() {
		Column resultColumn = new AttributeColumnFactory().create(new IntegerType());
		resultColumn.setName("iso_year");
		resultColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("year iso"))));
		return resultColumn;
	}

	private Column createDecadeColumn() {
		Column resultColumn = new AttributeColumnFactory().create(new IntegerType());
		resultColumn.setName("decade");
		resultColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("decade"))));
		return resultColumn;
	}

	private Column createYearColumn() {
		Column yearColumn = new AttributeColumnFactory().create(new IntegerType());
		yearColumn.setName("year");
		yearColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("year"))));
		return yearColumn;
	}

	private Column createQuarterColumn() {
		Column quarterColumn = new AttributeColumnFactory().create(new IntegerType());
		quarterColumn.setName("quarter_of_year");
		quarterColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("quarter of year"))));
		return quarterColumn;
	}

	private Column createCodeColumn() {
		Column codeColumn = new CodeColumnFactory().createDefault();
		codeColumn.setName("day_code");
		codeColumn.setDataType(new TextType(10));
		codeColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("day code"))));
		return codeColumn;
	}

	private Column createDayColumn() {
		Column dayColumn = new AttributeColumnFactory().create(new DateType());
		dayColumn.setName("the_day");
		dayColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("the day"))));
		return dayColumn;
	}

	private Column createMonthColumn() {
		Column monthColumn = new AttributeColumnFactory().create(new IntegerType());
		monthColumn.setName("month_of_year");
		monthColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("month of year"))));
		return monthColumn;
	}

	private Column createIsoWeekColumn() {
		Column isoWeekColumn = new AttributeColumnFactory().create(new IntegerType());
		isoWeekColumn.setName("week_of_iso_year");
		isoWeekColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("week of year iso"))));
		return isoWeekColumn;
	}

	@Override
	public PeriodType getManagedPeriodType() {
		return PeriodType.DAY;
	}

}

==> cube-manager-3.3.0-3.3.0-sources.jar: org/gcube/data/analysis/tabulardata/cube/time/DayCodelistCreator.java <==
package org.gcube.data.analysis.tabulardata.cube.time;

import java.util.Arrays;
import java.util.List;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.gcube.data.analysis.tabulardata.cube.data.DatabaseWrangler;
import org.gcube.data.analysis.tabulardata.cube.metadata.CubeMetadataWrangler;
import org.gcube.data.analysis.tabulardata.model.column.Column;
import org.gcube.data.analysis.tabulardata.model.column.factories.AnnotationColumnFactory;
import org.gcube.data.analysis.tabulardata.model.column.factories.CodeColumnFactory;
import org.gcube.data.analysis.tabulardata.model.column.factories.IdColumnFactory;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.IdColumnType;
import org.gcube.data.analysis.tabulardata.model.datatype.DateType;
import org.gcube.data.analysis.tabulardata.model.datatype.IntegerType;
import org.gcube.data.analysis.tabulardata.model.datatype.TextType;
import org.gcube.data.analysis.tabulardata.model.metadata.common.ImmutableLocalizedText;
import org.gcube.data.analysis.tabulardata.model.metadata.common.LocalizedText;
import org.gcube.data.analysis.tabulardata.model.metadata.common.NamesMetadata;
import org.gcube.data.analysis.tabulardata.model.metadata.table.TimePeriodTypeMetadata;
import org.gcube.data.analysis.tabulardata.model.table.Table;
import org.gcube.data.analysis.tabulardata.model.table.type.TimeCodelistTableType;
import org.gcube.data.analysis.tabulardata.model.time.PeriodType;

import com.google.common.collect.Lists;

@Singleton
public class DayCodelistCreator implements TimeCodelistCreator {

	@Inject
	DatabaseWrangler dbWrangler;

	@Inject
	CubeMetadataWrangler cmWrangler;

	@Override
	public Table createTable() {
		Table dayCodelist = createTableMeta();

		String tableName = createTableOnDBWithColumns(dayCodelist.getColumns());
		dayCodelist.setName(tableName);
		
		return cmWrangler.save(dayCodelist, false);
	}

	private Table createTableMeta() {
		List<Column> columns = Lists.newArrayList(IdColumnFactory.create(), createCodeColumn(), createDayColumn(),
				createMonthColumn(), createQuarterColumn(), createYearColumn(), createDecadeColumn(),
				createIsoWeekColumn(), createIsoYearColumn());
		Table dayCodelist = new Table(new TimeCodelistTableType());
		dayCodelist.setColumns(columns);
		dayCodelist.setMetadata(new TimePeriodTypeMetadata(getManagedPeriodType()));
		return dayCodelist;
	}

	private String createTableOnDBWithColumns(List<Column> columns) {
		String tableName = dbWrangler.createTable();
		for (Column column : columns) {
			if (column.getColumnType() instanceof IdColumnType)
				continue;
			dbWrangler.addColumn(tableName, column.getName(), column.getDataType());
			dbWrangler.setNullable(tableName, column.getName(), false);
			if (column.getColumnType() instanceof CodeColumnType)
				dbWrangler.createUniqueIndex(tableName, column.getName());
		}
		dbWrangler.createInsertUpdateTriggerOnTable("update_time_dimension_"+tableName, tableName, "update_gregorian_day_dimension");
		return tableName;
	}

	private Column createIsoYearColumn() {
		Column resultColumn = new AnnotationColumnFactory().create(new IntegerType());
		resultColumn.setName("iso_year");
		resultColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("year iso"))));
		return resultColumn;
	}

	private Column createDecadeColumn() {
		Column resultColumn = new AnnotationColumnFactory().create(new IntegerType());
		resultColumn.setName("decade");
		resultColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("decade"))));
		return resultColumn;
	}

	private Column createYearColumn() {
		Column yearColumn = new AnnotationColumnFactory().create(new IntegerType());
		yearColumn.setName("year");
		yearColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("year"))));
		return yearColumn;
	}

	private Column createQuarterColumn() {
		Column quarterColumn = new AnnotationColumnFactory().create(new IntegerType());
		quarterColumn.setName("quarter_of_year");
		quarterColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("quarter of year"))));
		return quarterColumn;
	}

	private Column createCodeColumn() {
		Column codeColumn = new CodeColumnFactory().createDefault();
		codeColumn.setName("day_code");
		codeColumn.setDataType(new TextType(10));
		codeColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("day code"))));
		return codeColumn;
	}

	private Column createDayColumn() {
		Column dayColumn = new AnnotationColumnFactory().create(new DateType());
		dayColumn.setName("the_day");
		dayColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("the day"))));
		return dayColumn;
	}

	private Column createMonthColumn() {
		Column monthColumn = new AnnotationColumnFactory().create(new IntegerType());
		monthColumn.setName("month_of_year");
		monthColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("month of year"))));
		return monthColumn;
	}

	private Column createIsoWeekColumn() {
		Column isoWeekColumn = new AnnotationColumnFactory().create(new IntegerType());
		isoWeekColumn.setName("week_of_iso_year");
		isoWeekColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("week of year iso"))));
		return isoWeekColumn;
	}

	@Override
	public PeriodType getManagedPeriodType() {
		return PeriodType.DAY;
	}

}
